@@ -23,15 +23,15 @@ sub prompt {
     say("What would you like to:");
     my @choices = ();
     # Repair
-    if ($test->can('repair')) {
+    if ($test->has_repair()) {
         say("  Y : Repair");
         push(@choices, 'Y');
     }
     # Skip
     say("  N : Skip");
     push(@choices, 'n');
-    # Diff
-    if ($test->can('diff')) {
+    # DIff
+    if ($test->has_diff()) {
         say("  D : Diff");
         push(@choices, 'd');
     }
@@ -42,20 +42,16 @@ sub prompt {
     say($action); 
     ReadMode 0;
     
-    # Execute and return, based on input. Return value is used for processing
-    # on_repair operations.
     given ($action) {
         when (/[Yy\n]/) { 
-            return $test->execute('repair') if ($test->can('repair'));
+            $test->repair() if ($test->has_repair());
         }
         when (/[Dd]/) { 
             # Show diff, loop through prompt again
-            $test->execute('diff') if ($test->can('diff'));
+            $test->diff() if ($test->has_diff());
             prompt($test);
         }
-        default {
-            return 0;
-        }
+        default {}
     }
 }
 
